@@ -123,7 +123,7 @@ class Text(interface):
         and the set returned at a particular character offset via Text::getAttributeRun.
         """
 
-        def addSelection(self, index):
+        def addSelection(self, startOffset, endOffset):
                 """
                 The result of calling addSelection on objects which already have
                 one selection present, and which do not include STATE_MULTISELECTABLE,
@@ -135,7 +135,7 @@ class Text(interface):
                 other reasons (for instance if the user does not have permission
                 to copy the text into the relevant selection buffer).
                 """
-                return Atspi.Text.add_selection(self.obj, index)
+                return Atspi.Text.add_selection(self.obj, startOffset, endOffset)
 
         def getAttributeRun(self, offset, includeDefaults=True):
                 """
@@ -274,6 +274,8 @@ class Text(interface):
                 to multiple character offsets, for instance if the glyph is a
                 ligature, the bounding box reported will include the entire glyph
                 and therefore may apply to more than one character offset. 
+                The returned values are meaningful only if the Text has
+                both STATE_VISIBLE and STATE_SHOWING.
                 @param : offset
                 the character offset of the character or glyph being queried.
                 @param : coordType
@@ -349,6 +351,8 @@ class Text(interface):
                 range. Negative values may be returned for the bounding box parameters
                 in the event that all or part of the text range is offscreen
                 or not mapped to the screen. 
+                The returned values are meaningful only if the Text has
+                both STATE_VISIBLE and STATE_SHOWING.
                 @param : startOffset
                 the offset of the first character in the specified range. 
                 @param : endOffset
