@@ -11,6 +11,6 @@
 #GNU General Public License for more details.
 #You should have received a copy of the GNU General Public License
 #along with this program; if not, write to the Free Software
-#Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+#Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
 
-from Pasy import PasyTestStep, PasyTestFunc, PasyTest
+from .Pasy import PasyTestStep, PasyTestFunc, PasyTest
